==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/ga-IE/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Sócmhainní a shanntar do: ainm',
    'bulk_update_warn'	=> 'Tá tú ar tí in eagar na hairíonna seo a leanas: úsáideoirí user_count. Tabhair faoi deara nach féidir leat tréithe úsáideora féin a athrú ag baint úsáide as an bhfoirm seo, agus ní mór duit athruithe a dhéanamh chuig d\'úsáideoir féin ina n-aonar.',
    'bulk_update_help'	=> 'Ceadaíonn an fhoirm seo duit il-úsáideoirí a thabhairt cothrom le dáta ag an am céanna. Líon isteach na réimsí is gá duit a athrú ach amháin. Ní dhéanfar aon réimsí fágtha gan athrú.',
    'current_assets'    => 'Seiceáil na sócmhainní faoi láthair don úsáideoir seo',
    'clone'             => 'Úsáideoir Clón',
    'contact_user'      => 'Ainm an Teagmhálaí',
    'edit'              => 'Athraigh Úsáideoir',
    'filetype_info'     => 'Is iad píopaí comhaid a cheadaítear png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'Stair le haghaidh: ainm',
    'info'				=> 'Eolas',
    'restore_user'		=> 'Cliceáil anseo chun iad a athchóiriú.',
    'last_login'        => 'Logáil isteach deireanach',
    'ldap_config_text'  => 'Is féidir suímh chumraíochta LDAP a fháil Admin> Settings. Socrófar an suíomh roghnaithe (roghnach) do gach úsáideoir a allmhairítear.',
    'print_assigned'    => 'Print All Assigned',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'Bogearraí Seiceáil amach chuig: ainm',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Féach Úsáideoir: ainm',
    'usercsv'           => 'Comhad CSV',
    'two_factor_admin_optin_help' => 'Ceadaíonn do shuímh riaracháin reatha forfheidhmiú roghnach fíordheimhnithe dhá fhachtóir.',
    'two_factor_enrolled' => 'Gléas 2FA Cláraithe',
    'two_factor_active'   => '2FA Gníomhach',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/ga-IE/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Sócmhainní a shanntar do: ainm',
    'bulk_update_warn'	=> 'Tá tú ar tí in eagar na hairíonna seo a leanas: úsáideoirí user_count. Tabhair faoi deara nach féidir leat tréithe úsáideora féin a athrú ag baint úsáide as an bhfoirm seo, agus ní mór duit athruithe a dhéanamh chuig d\'úsáideoir féin ina n-aonar.',
    'bulk_update_help'	=> 'Ceadaíonn an fhoirm seo duit il-úsáideoirí a thabhairt cothrom le dáta ag an am céanna. Líon isteach na réimsí is gá duit a athrú ach amháin. Ní dhéanfar aon réimsí fágtha gan athrú.',
    'current_assets'    => 'Seiceáil na sócmhainní faoi láthair don úsáideoir seo',
    'clone'             => 'Úsáideoir Clón',
    'contact_user'      => 'Ainm an Teagmhálaí',
    'edit'              => 'Athraigh Úsáideoir',
    'filetype_info'     => 'Is iad píopaí comhaid a cheadaítear png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'Stair le haghaidh: ainm',
    'info'				=> 'Eolas',
    'restore_user'		=> 'Cliceáil anseo chun iad a athchóiriú.',
    'last_login'        => 'Logáil isteach deireanach',
    'ldap_config_text'  => 'Is féidir suímh chumraíochta LDAP a fháil Admin> Settings. Socrófar an suíomh roghnaithe (roghnach) do gach úsáideoir a allmhairítear.',
    'print_assigned'    => 'Print All Assigned',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'Bogearraí Seiceáil amach chuig: ainm',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Féach Úsáideoir: ainm',
    'usercsv'           => 'Comhad CSV',
    'two_factor_admin_optin_help' => 'Ceadaíonn do shuímh riaracháin reatha forfheidhmiú roghnach fíordheimhnithe dhá fhachtóir.',
    'two_factor_enrolled' => 'Gléas 2FA Cláraithe',
    'two_factor_active'   => '2FA Gníomhach',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];
